@@ -13,19 +13,19 @@
 from cement.utils.misc import minimal_logger
 
 from ebcli.objects.platform import PlatformVersion
-from . import containerops
-from . import dockerrun
+from ebcli.containers import containerops
+from ebcli.containers import dockerrun
 
-from .envvarcollector import EnvvarCollector
-from .pathconfig import PathConfig
-from .fshandler import ContainerFSHandler, MultiContainerFSHandler
-from .generic_container import GenericContainer
-from .multicontainer import MultiContainer
-from .preconfigured_container import PreconfiguredContainer
-from ..objects.exceptions import NotSupportedError, NotFoundError, \
+from ebcli.containers.envvarcollector import EnvvarCollector
+from ebcli.containers.pathconfig import PathConfig
+from ebcli.containers.fshandler import ContainerFSHandler, MultiContainerFSHandler
+from ebcli.containers.generic_container import GenericContainer
+from ebcli.containers.multicontainer import MultiContainer
+from ebcli.containers.preconfigured_container import PreconfiguredContainer
+from ebcli.objects.exceptions import NotSupportedError, NotFoundError, \
         NotInitializedError
-from ..operations import platformops, solution_stack_ops
-from ..resources.strings import strings
+from ebcli.operations import platform_version_ops, solution_stack_ops
+from ebcli.resources.strings import alerts, strings
 
 
 LOG = minimal_logger(__name__)
@@ -100,14 +100,13 @@ def _get_solution_stack():
     solution_string = solution_stack_ops.get_default_solution_stack()
     soln_stk = None
 
-    # Test out sstack and tier before we ask any questions (Fast Fail)
     if solution_string:
-        if PlatformVersion.is_valid_arn(solution_string):
+        if PlatformVersion.is_custom_platform_arn(solution_string):
             try:
-                platformops.describe_custom_platform_version(solution_string)
+                platform_version_ops.describe_custom_platform_version(solution_string)
             except NotFoundError:
                 raise NotFoundError(
-                    'Platform arn {} does not appear to be valid'.format(solution_string)
+                    alerts['platform.invalidstring'].format(solution_string)
                 )
 
             soln_stk = PlatformVersion(solution_string)
@@ -115,7 +114,7 @@ def _get_solution_stack():
             try:
                 soln_stk = solution_stack_ops.find_solution_stack_from_string(solution_string)
 
-                if PlatformVersion.is_valid_arn(soln_stk):
+                if PlatformVersion.is_eb_managed_platform_arn(soln_stk):
                     soln_stk = PlatformVersion.get_platform_name(soln_stk)
 
             except NotFoundError:
