@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -16,7 +16,6 @@ import warnings
 import getpass
 import sys
 import logging
-import signal
 
 import colorama
 import pydoc
@@ -24,42 +23,26 @@ from botocore.compat import six
 from six import print_
 from six.moves import input
 
-from ..core import ebglobals
-from ..objects.exceptions import ValidationError
-from ..resources.strings import prompts, strings
+from ebcli.core import ebglobals
+from ebcli.objects.exceptions import ValidationError
+from ebcli.resources.strings import prompts, strings
 
 LOG = logging.getLogger(__name__)
 
-color_on = False
-
-
-def start_color():
-    global color_on
-    if not color_on and term_is_colorable():
-        colorama.init()
-        color_on = True
-    return color_on
-
 
 def term_is_colorable():
-    return sys.stdout.isatty()  # Live terminal
+    return sys.stdout.isatty()
 
 
 def bold(string):
     s = _convert_to_string(string)
-    if start_color():
+    if term_is_colorable():
+        colorama.init()
         return colorama.Style.BRIGHT + s + colorama.Style.NORMAL
     else:
         return s
 
 
-def reset_all_color():
-    if start_color():
-        return colorama.Style.RESET_ALL
-    else:
-        return ''
-
-
 def _remap_color(color):
     if color.upper() == 'ORANGE':
         return 'YELLOW'
@@ -70,7 +53,8 @@ def _remap_color(color):
 
 def color(color, string):
     s = _convert_to_string(string)
-    if start_color():
+    if term_is_colorable():
+        colorama.init()
         color = _remap_color(color)
         color_code = getattr(colorama.Fore, color.upper())
         return color_code + s + colorama.Fore.RESET
@@ -80,7 +64,8 @@ def color(color, string):
 
 def on_color(color, string):
     s = _convert_to_string(string)
-    if start_color():
+    if term_is_colorable():
+        colorama.init()
         color = _remap_color(color)
         color_code = getattr(colorama.Back, color.upper())
         return color_code + s + colorama.Back.RESET
@@ -152,25 +137,22 @@ def log_error(message):
 
 
 def get_input(output, default=None):
-    # importing readline module allows user to use bash commands
-    ## such as Ctrl+A etc.
-    ## Only works on non windows
     try:
         import readline
     except ImportError:
-        # oh well, we tried
         pass
 
-    # Trim spaces
     output = next(_convert_to_strings([output]))
-    result = input(output + ': ').strip()
-    if not result:
-        result = default
-    return result
+    result = _get_input(output)
+
+    return result or default
+
+
+def _get_input(output):
+    return input(output + ': ').strip()
 
 
 def echo_with_pager(output):
-    # pydoc.pager handles pipes and everything
     pydoc.pager(output)
 
 
@@ -202,16 +184,15 @@ def prompt_for_environment_name(default_name='myEnv',
       It cannot start or end with a hyphen.
     """
     constraint_pattern = '^[a-z0-9][a-z0-9-]{2,38}[a-z0-9]$'
-    #  Edit default name to fit standards.
 
     if not re.match(constraint_pattern, default_name):
-        if not re.match('^[a-zA-Z0-9].*', default_name):  # begins correctly
+        if not re.match('^[a-zA-Z0-9].*', default_name):
             default_name = 'eb-' + default_name
         default_name = default_name.replace('_', '-')
         default_name = re.sub('[^a-z0-9A-Z-]', '', default_name)
         if len(default_name) > 40:
             default_name = default_name[:39]
-        if not re.match('.*[a-zA-Z0-9]$', default_name):  # end correctly
+        if not re.match('.*[a-zA-Z0-9]$', default_name):
             default_name += '0'
 
     while True:
@@ -247,10 +228,6 @@ def validate_action(output, expected_input):
 
 
 def prompt_for_cname(default=None):
-    # Validate cname: spec says:
-    # Constraint: Must be from 4 to 40 characters in length.
-    # The name can contain only letters, numbers, and hyphens.
-    # It cannot start or end with a hyphen.
     while True:
         echo('Enter DNS CNAME prefix')
         if default:
@@ -305,8 +282,10 @@ def get_boolean_response(text=None):
         string = '(Y/n)'
     response = get_input(string, default='y').lower()
     while response not in ('y', 'n', 'yes', 'no'):
-        echo(strings['prompt.invalid'],
-                             strings['prompt.yes-or-no'])
+        echo(
+            strings['prompt.invalid'],
+            strings['prompt.yes-or-no']
+        )
         response = prompt('Y/n', default='y').lower()
 
     if response in ('y', 'yes'):
@@ -349,7 +328,7 @@ class EventStreamer(object):
          Removes the self.prompt from the screen
         """
         if self.eventcount < 1:
-            return  # Nothing to clean up
+            return
         length = len(self.prompt) + 3  # Cover up "^C" character as well
         print_('\r'.ljust(length))
 
