@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -15,16 +15,17 @@ from __future__ import print_function
 import datetime
 import fileinput
 import os
+import re
+import subprocess
 import sys
 
 from cement.utils.misc import minimal_logger
 from cement.utils.shell import exec_cmd
 
-from ebcli.lib import codecommit, utils
+from ebcli.lib import utils
 from ebcli.core import fileoperations, io
-from ebcli.objects.exceptions import(
+from ebcli.objects.exceptions import (
     CommandError,
-    GitRemoteNotSetupError,
     NotInitializedError,
     NoSourceControlError
 )
@@ -59,7 +60,6 @@ class SourceControl(object):
 
     @staticmethod
     def get_source_control():
-        # First check for setting in config file
         try:
             git_installed = fileoperations.get_config_setting('global', 'sc')
         except NotInitializedError:
@@ -84,7 +84,6 @@ class NoSC(SourceControl):
         return None
 
     def get_version_label(self):
-        # use timestamp as version
         suffix = datetime.datetime.now().strftime("%y%m%d_%H%M%S")
         return 'app-' + suffix
 
@@ -129,12 +128,17 @@ class Git(SourceControl):
         if exitcode == 128:
             # 128 = No HEAD
             if "HEAD" in stderr:
-                LOG.debug('An error occurred while handling git command.'
-                                   '\nError code: ' + str(exitcode) + ' Error: ' +
-                                   stderr)
-                raise CommandError('git could not find the HEAD; most likely because there are no commits present')
+                LOG.debug(
+                    'An error occurred while handling git command.\nError code: '
+                    + str(exitcode)
+                    + ' Error: '
+                    + stderr
+                )
+                raise CommandError(
+                    'git could not find the HEAD; '
+                    'most likely because there are no commits present'
+                )
 
-        # Something else happened
         raise CommandError('An error occurred while handling git command.'
                            '\nError code: ' + str(exitcode) + ' Error: ' +
                            stderr)
@@ -145,57 +149,45 @@ class Git(SourceControl):
             self._run_cmd(['git', 'describe', '--always', '--abbrev=4'])
 
         version_label = 'app-{}-{:%y%m%d_%H%M%S}'.format(stdout, datetime.datetime.now())
-        #Replace dots with underscores
         return version_label.replace('.', '_')
 
     def untracked_changes_exist(self):
-        stdout, stderr, exitcode = self._run_cmd(['git', 'diff', '--numstat'])
-        LOG.debug('git diff --numstat result: ' + stdout +
-                  ' with errors: ' + stderr)
-        if stdout:
-            return True
-        return False
+        try:
+            result = subprocess.check_output(['git', 'diff', '--numstat'])
+
+            if isinstance(result, bytes):
+                result = result.decode()
+
+            LOG.debug('Result of `git diff --numstat`: ' + result)
+        except subprocess.CalledProcessError as e:
+            LOG.debug('`git diff --numstat` resulted in an error: ' + str(e))
 
     def get_current_repository(self):
-        # it's possible 'origin' isn't the name of their remote so attempt to get their current remote
         current_branch = self.get_current_branch()
+        get_remote_name_command = ['git', 'config', '--get', 'branch.{0}.remote'.format(current_branch)]
+        LOG.debug(
+            'Getting current repository name based on the current branch name:'
+            '{0}'.format(' '.join(get_remote_name_command))
+        )
+
         stdout, stderr, exitcode = self._run_cmd(
-            ['git', 'config', '--get', 'branch.{0}.remote'.format(current_branch)], handle_exitcode=False)
+            get_remote_name_command,
+            handle_exitcode=False
+        )
 
         current_remote = stdout
         if exitcode != 0:
             LOG.debug("No remote found for the current working directory.")
             current_remote = "origin"
-        else:
-            LOG.debug("Found remote branch {0} that is currently being tracked".format(current_remote))
-            try:
-                if current_remote.split('/') > 1:
-                    # TODO: To confirm a url like this is really hacky I should change it.
-                    # This assumes the remote they have is a raw address and get the repository name from that. It works
-                    # for the way that I use it but it might fail if it is used to get repos that were not created by
-                    # the eb cli
-                    LOG.debug("Assuming remote branch is a raw url, returning this as the repository")
-                    return stdout.split('/')[-1]
-            except TypeError:
-                LOG.debug("stdout from git config branch remote was not a string: {0}".format(stdout))
-                current_remote = "origin"
 
-        # We want the name of the repository not the remote it is saved as locally
-        stdout, stderr, exitcode = self._run_cmd(
-            ['git', 'config', '--get', 'remote.{0}.url'.format(current_remote)], handle_exitcode=False)
-        if exitcode != 0:
-            LOG.debug('No remote repository found')
-            return
-        else:
-            self._handle_exitcode(exitcode, stderr)
-
-        LOG.debug('git config --get remote.origin.url: ' + stdout)
-        # Need to parse branch from ref manually because "--short" is
-        # not supported on git < 1.8
-        return stdout.split('/')[-1]
+        LOG.debug('Found remote: {}'.format(current_remote))
+        return current_remote
 
     def get_current_branch(self):
-        stdout, stderr, exitcode = self._run_cmd(['git', 'rev-parse', '--abbrev-ref', 'HEAD'], handle_exitcode=False)
+        revparse_command = ['git', 'rev-parse', '--abbrev-ref', 'HEAD']
+        LOG.debug('Getting current branch name by performing `{0}`'.format(' '.join(revparse_command)))
+
+        stdout, stderr, exitcode = self._run_cmd(revparse_command, handle_exitcode=False)
 
         if stdout.strip() == 'HEAD':
             io.log_warning('Git is in a detached head state. Using branch "default".')
@@ -203,18 +195,25 @@ class Git(SourceControl):
         else:
             self._handle_exitcode(exitcode, stderr)
 
+        LOG.debug(stdout)
+
         return stdout
 
     def get_current_commit(self):
+        latest_commit_command = ['git', 'rev-parse', '--verify', 'HEAD']
+        LOG.debug('Getting current commit by performing `{0}`'.format(' '.join(latest_commit_command)))
+
         stdout, stderr, exitcode = self._run_cmd(
-            ['git', 'rev-parse', '--verify', 'HEAD'], handle_exitcode=False)
+            latest_commit_command,
+            handle_exitcode=False
+        )
         if exitcode != 0:
             LOG.debug('No current commit found')
             return
         else:
             self._handle_exitcode(exitcode, stderr)
 
-        LOG.debug('git rev-parse --verify HEAD result: ' + stdout)
+        LOG.debug(stdout)
         return stdout
 
     def do_zip_submodule(self, main_location, sub_location, staged=False, submodule_dir=None):
@@ -232,15 +231,13 @@ class Git(SourceControl):
                                                   '-o', sub_location, commit_id])
         io.log_info('git archive output: {0}'.format(stderr))
 
-        # append and remove the submodule archive
         fileoperations.zip_append_archive(main_location, sub_location)
         fileoperations.delete_file(sub_location)
 
     def do_zip(self, location, staged=False):
         cwd = os.getcwd()
         try:
-            # must be in project root for git archive to work.
-            fileoperations._traverse_to_project_root()
+            fileoperations.ProjectRoot.traverse()
 
             if staged:
                 commit_id, stderr, exitcode = self._run_cmd(['git', 'write-tree'])
@@ -258,13 +255,20 @@ class Git(SourceControl):
             must_zip_submodules = fileoperations.get_config_setting('global', 'include_git_submodules')
 
             if must_zip_submodules:
-                # individually zip submodules if there are any
                 stdout, stderr, exitcode = self._run_cmd(['git', 'submodule', 'foreach', '--recursive'])
 
                 for index, line in enumerate(stdout.splitlines()):
                     submodule_dir = line.split(' ')[1].strip('\'')
                     os.chdir(os.path.join(project_root, submodule_dir))
-                    self.do_zip_submodule(location, "{0}_{1}".format(location, str(index)), staged=staged, submodule_dir=submodule_dir)
+                    self.do_zip_submodule(
+                        location,
+                        "{0}_{1}".format(
+                            location,
+                            str(index)
+                        ),
+                        staged=staged,
+                        submodule_dir=submodule_dir
+                    )
 
         finally:
             os.chdir(cwd)
@@ -276,8 +280,6 @@ class Git(SourceControl):
 
     def is_setup(self):
         if fileoperations.is_git_directory_present():
-            # We know that the directory has git, but
-            # is git on the path?
             if not fileoperations.program_is_installed('git'):
                 raise CommandError(strings['sc.gitnotinstalled'])
             else:
@@ -294,14 +296,14 @@ class Git(SourceControl):
                         return
 
         with open('.gitignore', 'a') as f:
-            f.write(os.linesep)
+            f.write('\n')
             for line in git_ignore:
-                f.write(line + os.linesep)
+                f.write('{}\n'.format(line))
 
     def clean_up_ignore_file(self):
         cwd = os.getcwd()
         try:
-            fileoperations._traverse_to_project_root()
+            fileoperations.ProjectRoot.traverse()
 
             in_section = False
             for line in fileinput.input('.gitignore', inplace=True):
@@ -316,27 +318,16 @@ class Git(SourceControl):
         finally:
             os.chdir(cwd)
 
-    def git_remote(self):
-        stdout, stderr, exitcode = self._run_cmd(['git', 'remote'])
-
-        if not stdout:
-            raise GitRemoteNotSetupError("""fatal: No configured push destination.
-Either specify the URL from the command-line or configure a remote repository using
-
-    git remote add <name> <url>
-
-and then push using the remote name
-
-    git push <name>
-
-""")
-
-        return stdout
-
     def push_codecommit_code(self):
         io.log_info('Pushing local code to codecommit with git-push')
 
-        stdout, stderr, exitcode = self._run_cmd(['git', 'push', self.git_remote(), self.get_current_branch()])
+        stdout, stderr, exitcode = self._run_cmd(
+            [
+                'git', 'push',
+                self.get_current_repository(),
+                self.get_current_branch()
+            ]
+        )
 
         if exitcode != 0:
             io.log_warning('Git is not able to push code: {0}'.format(exitcode))
@@ -346,33 +337,70 @@ and then push using the remote name
             self._handle_exitcode(exitcode, stderr)
 
     def setup_codecommit_remote_repo(self, remote_url):
-        stdout, stderr, exitcode = self._run_cmd(['git', 'remote', 'add', self.codecommit_remote_name, remote_url], handle_exitcode=False)
+        self.verify_url_is_a_codecommit_url(remote_url)
+        remote_add_command = ['git', 'remote', 'add', self.codecommit_remote_name, remote_url]
+        LOG.debug('Adding remote: {0}'.format(' '.join(remote_add_command)))
+
+        stdout, stderr, exitcode = self._run_cmd(remote_add_command, handle_exitcode=False)
 
-        # Setup the remote repository with code commit
         if exitcode != 0:
             if exitcode == 128:
-                LOG.debug("git remote already exists modifying to new url: {0}".format(remote_url))
-                self._run_cmd(['git', 'remote', 'set-url', self.codecommit_remote_name, remote_url])
-                self._run_cmd(['git', 'remote', 'set-url', '--push', self.codecommit_remote_name, remote_url])
+                remote_set_url_command = [
+                    'git', 'remote', 'set-url',
+                    self.codecommit_remote_name,
+                    remote_url
+                ]
+                LOG.debug(
+                    'Remote already exists, performing: {0}'.format(
+                        ' '.join(remote_set_url_command)
+                    )
+                )
+                self._run_cmd(remote_set_url_command)
+
+                remote_set_url_with_push_command = [
+                    'git',
+                    'remote',
+                    'set-url',
+                    '--push',
+                    self.codecommit_remote_name,
+                    remote_url
+                ]
+                LOG.debug(
+                    '                {0}'.format(
+                        ' '.join(remote_set_url_with_push_command)
+                    )
+                )
+                self._run_cmd(remote_set_url_with_push_command)
             else:
-                LOG.debug("Error setting up git config for code commit: {0}".format(stderr))
+                LOG.debug("Error setting up git config for CodeCommit: {0}".format(stderr))
                 return
         else:
-            self._run_cmd(['git', 'remote', 'set-url', '--add', '--push', self.codecommit_remote_name, remote_url])
+            remote_set_url_with_add_push_command = [
+                'git', 'remote', 'set-url',
+                '--add',
+                '--push',
+                self.codecommit_remote_name,
+                remote_url
+            ]
+            LOG.debug(
+                'Setting remote URL and pushing to it: {0}'.format(
+                    ' '.join(remote_set_url_with_add_push_command)
+                )
+            )
+            self._run_cmd(remote_set_url_with_add_push_command)
             self._handle_exitcode(exitcode, stderr)
 
         LOG.debug('git remote result: ' + stdout)
 
     def setup_new_codecommit_branch(self, branch_name):
-        # Get fetch to ensure the remote repository is up to date
+        LOG.debug("Setting up CodeCommit branch")
+
         self.fetch_remote_branches(self.codecommit_remote_name)
 
-        # Attempt to check out the desired branch, if it doesn't exist create it from the current HEAD
         self.checkout_branch(branch_name, create_branch=True)
 
-        # Push the current code and set the remote as the current working remote
         stdout, stderr, exitcode = self._run_cmd(
-            ['git', 'push', '-u', self.git_remote(), branch_name],
+            ['git', 'push', '-u', self.codecommit_remote_name, branch_name],
             handle_exitcode=False
         )
 
@@ -385,10 +413,8 @@ and then push using the remote name
 
         LOG.debug('git push result: ' + stdout)
 
-        # Get fetch to ensure the remote repository is up to date because we just pushed a new branch
         self.fetch_remote_branches(self.codecommit_remote_name)
 
-        # Set the remote branch up so it's not using the presigned remote OR if the push failed.
         stdout, stderr, exitcode = self._run_cmd(
             [
                 'git',
@@ -404,17 +430,20 @@ and then push using the remote name
 
         LOG.debug('git branch result: ' + stdout)
 
-    def setup_existing_codecommit_branch(self, branch_name):
-        # Get fetch to ensure the remote repository is up to date
-        self.fetch_remote_branches(self.codecommit_remote_name)
+    def setup_existing_codecommit_branch(self, branch_name, remote_url=None):
+        self.fetch_remote_branches(self.codecommit_remote_name, remote_url)
 
-        # Attempt to check out the desired branch, if it doesn't exist create it from the current HEAD
         self.checkout_branch(branch_name, create_branch=True)
 
-        # Setup the remote branch with the local git directory
         stdout, stderr, exitcode = self._run_cmd(
-            ['git', 'branch', '--set-upstream-to', "{0}/{1}".format(self.codecommit_remote_name, branch_name)],
-            handle_exitcode=False)
+            [
+                'git', 'branch', '--set-upstream-to', "{0}/{1}".format(
+                    self.codecommit_remote_name,
+                    branch_name
+                )
+            ],
+            handle_exitcode=False
+        )
 
         if exitcode != 0:
             LOG.debug('git branch --set-upstream-to error: ' + stderr)
@@ -425,7 +454,6 @@ and then push using the remote name
         return True
 
     def checkout_branch(self, branch_name, create_branch=False):
-        # Attempt to checkout an existing branch and if it doesn't exist create a new one.
         stdout, stderr, exitcode = self._run_cmd(['git', 'checkout', branch_name], handle_exitcode=False)
 
         if exitcode != 0:
@@ -433,8 +461,11 @@ and then push using the remote name
             LOG.debug(stderr)
             if exitcode == 1:
                 if create_branch:
-                    LOG.debug("Could not checkout branch '{0}', creating the branch locally with current HEAD".format(branch_name))
-                    stdout, stderr, exitcode = self._run_cmd(['git', 'checkout', '-b', branch_name])
+                    LOG.debug(
+                        "Could not checkout branch '{0}', creating the branch "
+                        "locally with current HEAD".format(branch_name)
+                    )
+                    self._run_cmd(['git', 'checkout', '-b', branch_name])
                 else:
                     return False
         return True
@@ -445,26 +476,40 @@ and then push using the remote name
         return stdout
 
     def create_initial_commit(self):
-        self._run_cmd(['touch', 'README'])
+        with open('README', 'w') as readme:
+            readme.write('')
         self._run_cmd(['git', 'add', 'README'])
-        stdout, stderr, exitcode = self._run_cmd(['git', 'commit', '--allow-empty', '-m', 'EB CLI initial commit'], handle_exitcode=False)
+        stdout, stderr, exitcode = self._run_cmd(
+            ['git', 'commit', '--allow-empty', '-m', 'EB CLI initial commit'],
+            handle_exitcode=False
+        )
 
-        if exitcode !=0:
+        if exitcode != 0:
             LOG.debug('git was not able to initialize an empty commit: {0}'.format(stderr))
 
         LOG.debug('git commit result: {0}'.format(stdout))
         return stdout
 
-    def fetch_remote_branches(self, remote):
-        stdout, stderr, exitcode = self._run_cmd(
-            [
+    def fetch_remote_branches(self, remote_name, remote_url=None):
+        if not remote_url:
+            fetch_command = [
                 'git',
                 'fetch',
-                self.git_remote(),
-                '+refs/heads/*:refs/remotes/{0}/*'.format(remote)
-            ],
-            handle_exitcode=False
-        )
+                self.get_current_repository(),
+                '+refs/heads/*:refs/remotes/{0}/*'.format(remote_name)
+            ]
+            LOG.debug('Fetching remote branches using remote name: {0}'.format(' '.join(fetch_command)))
+        else:
+            self.verify_url_is_a_codecommit_url(remote_url)
+
+            fetch_command = [
+                'git',
+                'fetch',
+                remote_url
+            ]
+            LOG.debug('Fetching remote branches using remote URL: {0}'.format(' '.join(fetch_command)))
+
+        stdout, stderr, exitcode = self._run_cmd(fetch_command, handle_exitcode=False)
 
         if stderr:
             LOG.debug('git fetch error: ' + stderr)
@@ -475,8 +520,9 @@ and then push using the remote name
         LOG.debug('Setup git config settings for code commit credentials')
         self._run_cmd(
             ['git', 'config', '--local', '--replace-all', 'credential.UseHttpPath', 'true'])
+
         self._run_cmd(
-            ['git', 'config', '--local', '--replace-all', 'credential.helper', '!aws codecommit credential-helper $@'])
+            ['git', 'config', '--local', '--replace-all', 'credential.helper', credential_helper_command()])
 
     def _run_cmd(self, cmd, handle_exitcode=True):
         stdout, stderr, exitcode = exec_cmd(cmd)
@@ -487,3 +533,15 @@ and then push using the remote name
         if handle_exitcode:
             self._handle_exitcode(exitcode, stderr)
         return stdout, stderr, exitcode
+
+    def verify_url_is_a_codecommit_url(self, remote_url):
+        codecommit_url_regex = re.compile(r'.*git-codecommit\..*\.amazonaws.com.*')
+
+        if not codecommit_url_regex.search(remote_url):
+            # Prevent communications with non-CodeCommit repositories because of unknown security implications
+            # Integration with non-CodeCommit repositories is not something Beanstalk presently supports
+            raise NoSourceControlError('Could not connect to repository located at {}'.format(remote_url))
+
+
+def credential_helper_command():
+    return '!aws codecommit credential-helper $@'
