@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,7 +11,19 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-# TODO: Merge into ebcli/lib/iam_role.py when the code has been merged in
+
+class logs_operations_constants(object):
+
+    class LOG_SOURCES(object):
+        ALL_LOG_SOURCES = 'all'
+        ENVIRONMENT_HEALTH_LOG_SOURCE = 'environment-health'
+        INSTANCE_LOG_SOURCE = 'instance'
+
+    class INFORMATION_FORMAT(object):
+        BUNDLE = 'bundle'
+        TAIL = 'tail'
+
+
 class iam_documents(object):
     EC2_ASSUME_ROLE_PERMISSION = '{"Version": "2008-10-17","Statement": [{"Action":' \
                                  ' "sts:AssumeRole","Principal": {"Service": ' \
@@ -44,7 +56,9 @@ class namespaces(object):
     ELB_POLICIES = 'aws:elb:policies'
     ROLLING_UPDATES = 'aws:autoscaling:updatepolicy:rollingupdate'
     VPC = 'aws:ec2:vpc'
+    SPOT = 'aws:ec2:instances'
     CLOUDWATCH_LOGS = 'aws:elasticbeanstalk:cloudwatch:logs'
+    CLOUDWATCH_ENVIRONMENT_HEALTH_LOGS = 'aws:elasticbeanstalk:cloudwatch:logs:health'
 
 
 class option_names(object):
@@ -82,8 +96,18 @@ class option_names(object):
     SYSTEM_TYPE = 'SystemType'
     VPC_ID = 'VPCId'
     STREAM_LOGS = 'StreamLogs'
+    CLOUDWATCH_ENVIRONMENT_HEALTH_LOGS_ENABLED = 'HealthStreamingEnabled'
     DELETE_ON_TERMINATE = 'DeleteOnTerminate'
     RETENTION_DAYS = 'RetentionInDays'
+    ENABLE_SPOT = 'EnableSpot'
+    ON_DEMAND_BASE_CAPACITY = 'SpotFleetOnDemandBase'
+    ON_DEMAND_PERCENTAGE_ABOVE_BASE_CAPACITY = 'SpotFleetOnDemandAboveBasePercentage'
+    SPOT_MAX_PRICE = 'SpotMaxPrice'
+    INSTANCE_TYPES = 'InstanceTypes'
+
+
+class option_values(object):
+    SYSTEM_TYPE__ENHANCED = 'enhanced'
 
 
 class elb_names(object):
@@ -94,3 +118,18 @@ class elb_names(object):
     CLASSIC_VERSION = 'classic'
     APPLICATION_VERSION = 'application'
     NETWORK_VERSION = 'network'
+
+
+class ec2_instance_statuses(object):
+    IN_SERVICE = 'InService'
+
+
+class platform_branch_lifecycle_states(object):
+    BETA = 'Beta'
+    SUPPORTED = 'Supported'
+    DEPRECATED = 'Deprecated'
+    RETIRED = 'Retired'
+
+
+class platform_version_lifecycle_states(object):
+    RECOMMENDED = 'Recommended'
